pysophia documentation — pysophia 0.1 documentation

### Navigation

- index
- modules |
- next |
- pysophia 0.1 documentation »

# pysophia documentation

This package provides Python bindings for sophia, a ligthweight DBM-like database. Available operations on a database are inserting a key-value pair, deleting it, or retrieving a value given its key. It is also possible to traverse the records of a database, in ascending or descending order.

## Installation

First install libsophia using this script (to be run from the source package directory if you have the source distribution, or from /tmp or similar). Then download the bindings (preferably from Github), and install them with:

    python setup.py install

If you want to check how the library performs, look at the benchmarks on the website of the author, and run the script `bench.py` located in the `tests` directory of this package, which will give you an idea of what performance you can expect from the module on your specific hardware.

## Contents

- Tutorial
  - Basics
  - Storing and deleting records
  - Retrieving records
  - Traversing records
  - Storing rich objects
  - Tuning
  - On threading
  - Cursors pitfall
  - Final note
- Reference
  - Main objects
  - Database models

## Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- pysophia 0.1 documentation »